@@ -59,7 +59,7 @@ class Remote_operation():
 
     def ssh_scp_get(self,local_file, remote_file):
         """
-        把本地文件上传到远程服务器
+        从远程服务器下载文件到本地
 
         """
 
@@ -73,15 +73,12 @@ class Remote_operation():
 
 class LinuxLocalOperation():
     def start_mock_server(self,mock_server_port):
-        self.stop_port_process(mock_server_port)
+        self.stop_mock_server(mock_server_port)
 
-    def stop_port_process(self,mock_server_port):
+    def stop_mock_server(self,mock_server_port):
         stop_port_process_cmd = "netstat -ntlp | grep ':"+str(mock_server_port)+" '  |  awk '{print $7}' |  awk -F '/' '{print $1}' | xargs kill -9"
         self.remote_operation.exec_remote_shell(stop_port_process_cmd)
 
-    def stop_mock_server(self):
-        self.remote_operation.exec_remote_shell("ps -ef | grep mock_server_code.py | grep -v grep | awk '{print $2}' | xargs kill -9")
-
 
 class LinuxRemoteOperation():
 
@@ -89,25 +86,22 @@ class LinuxRemoteOperation():
         self.remote_operation = Remote_operation(remote_mock_server_machine)
 
     def start_mock_server(self,mock_server_port):
-        self.stop_port_process(mock_server_port)
+        self.stop_mock_server(mock_server_port)
         self.remote_operation.ssh_scp_put("mock_server_code.py", "mock_server_code.py")
         self.remote_operation.exec_remote_shell("nohup python mock_server_code.py > /dev/null   2>&1 &")
 
-    def stop_port_process(self,mock_server_port):
+    def stop_mock_server(self,mock_server_port):
         stop_port_process_cmd = "netstat -ntlp | grep ':"+str(mock_server_port)+" '  |  awk '{print $7}' |  awk -F '/' '{print $1}' | xargs kill -9"
         self.remote_operation.exec_remote_shell(stop_port_process_cmd)
 
-    def stop_mock_server(self):
-        self.remote_operation.exec_remote_shell("ps -ef | grep mock_server_code.py | grep -v grep | awk '{print $2}' | xargs kill -9")
-
 
 class WindoxLocalOperation:
 
     def start_mock_server(self,mock_server_port):
-        self.stop_port_process(mock_server_port)
+        self.stop_mock_server(mock_server_port)
         subprocess.Popen("python  mock_server_code.py",stdout=None)
 
-    def stop_port_process(self,mock_server_port):
+    def stop_mock_server(self,mock_server_port):
         find_port = 'netstat -aon | findstr %s' % mock_server_port
         result = os.popen(find_port)
         for line in result.readlines():
@@ -115,8 +109,6 @@ class WindoxLocalOperation:
             kill_pid_cmd = 'taskkill -f -pid %s' % pid
             subprocess.Popen(kill_pid_cmd)
 
-    def stop_mock_server(self):
-        pass
 
 
 
@@ -148,7 +140,7 @@ class MockServerClass:
             elif platform.system() == "Linux":
                 self.__system_operation = LinuxLocalOperation()
         else:
-            self.system_operation = LinuxRemoteOperation(remote_mock_server_machine)
+            self.__system_operation = LinuxRemoteOperation(remote_mock_server_machine)
 
         mock_server_listen_port = mock_server_port
         mock_server_ip = self.__remote_mock_server_machine["ip"] if self.__remote_mock_server_machine else "127.0.0.1"
@@ -226,11 +218,9 @@ if __name__=="__main__":
         sleep(4)
 
     #此函数用于,启动模拟服务之前,先把特定端口号的进程kill调
-    def stop_port_process(self):
-        self.__system_operation.stop_port_process(self.mock_server_port)
-
     def stop_mock_server(self):
-        self.__system_operation.stop_mock_server()
+        self.__system_operation.stop_mock_server(self.mock_server_port)
+
 
     #返回 模拟服务接收到的请求日志
     def get_mock_server_request_data_list(self):
